@@ -168,14 +168,20 @@ get_ui = function()
 		        column(width=3, class="col-side-left",  
 		          tags$div(HTML('Here you can import response data in normalized or long format as can be typically exported',
 		                   'from databases. Dexter expects the columns:<ul><li>booklet_id</li><li>person_id</li><li>item_id</li>', 
-		                   '<li>response</li><li>item_position (optional)</li></ul>',
-		                   'Each row should contain a single response.'),
+		                   '<li>response</li></ul>',
+		                   'Each row should contain a single response.<br/>For each booklet in the respons data, dexter needs to know',
+		                   'which items that booklet should contain. Missing responses in the data will then be replaced with "NA".',
+		                   'You specify this in the design file which should conain the following columns:',
+		                   '<ul><li>booklet_id</li><li>item_id</li><li>item_position (optional)</li><ul><br/>',
+		                   "If all booklet_id's in the data are already known in the dexter-project, you don't need to specify a design."),
 		                  id='help-import-data-file-long', class='collapse',style="margin-bottom:1em;"),
 		          fileInput('data_file_long', 'Data file',width='100%'),
+		          fileInput('design_file_long','Design file',width='100%'),
 		          uiOutput('show_data_unknown_rsp_long'),
 		          withBusyIndicatorUI(actionButton('go_import_data_long','Import',class='btn btn-primary')),
 		          htmlOutput('data_import_result_long')),
-		        column(width=9, tableOutput('data_preview_long'))))),
+		        column(width=5, tableOutput('data_preview_long')),
+		        column(width=4, tableOutput('design_preview_long'))))),
 		             
 		             
 		  value = 'data_pane',style="padding-left:10px;"),
